CRole

Enum CRole 

pub enum CRole {
    Enumerator,
    Enum,
    Function,
    FunctionParam,
    Member,
    Macro,
    Var,
    Type,
    Struct,
    Union,
}
Describes a C role that has been observed in the wild, i.e. one of the known inventory file declared at least one line with the type c:{role} if you would like one added please open a feature request

Variants



Enumerator

Describes a C enumerator see also the sphinx docs



Enum

Describes a C enum see also the sphinx docs



Function

Describes a C function with a signature as written in C see also the sphinx docs



FunctionParam

see also the sphinx docs



Member

A C variable, is an alias for CRole::Var see also the sphinx docs



Macro

Describes a C macro, i.e. a #define without the replacement text see also the sphinx docs



Var

A C variable, equivalent to CRole::Member see also the sphinx docs



Type

Describes a C type as defined by either a typedef or alias see also the sphinx docs



Struct

Describes a C struct see also the sphinx docs



Union

Describes a C union see also the sphinx docs