pub enum CmakeRole {
Show 17 variants
Command,
CpackGen,
Envvar,
Generator,
Genex,
Guide,
Manual,
Module,
Policy,
PropCache,
PropDir,
PropGbl,
PropInst,
PropSf,
PropTest,
PropTgt,
Variable,
}Expand description
The various known domains and roles used in sphinx inventory files
Variants
Command
A cmake command in a cmake file like set()
or add_executable() not to be confused with a command line
command like cmake build see the cmake docs for more info
CpackGen
Cpack generators create packages out of artifacts such as installers see more
Envvar
A environment variable that cmake can use, e.g. CMAKE_CONFIG_DIR see more for more
Generator
A cmake Generator is responsible for writing the input files for a native build system. see more
Genex
A cmake generator expression see more
Guide
refers to a gide page such as the tutorial in the documentation
Manual
Refers to a man page such as cmake(1)
Module
A cmake module designed for reuse. see more
Policy
policies introduce behavior changes while preserving compatibility for existing project releases. see more
PropCache
A cache property see more
PropDir
A directory property see more
PropGbl
A global cmake property see more
PropInst
Properties on installed files see more
PropSf
Properties on source files see more
PropTest
Properties on tests see more
PropTgt
A target property see more
Variable
A cmake variable. can be set by cmake itself or by project code see more